@@ -9,7 +9,7 @@ Boolean gcverbose	= FALSE;	/* -G */
 Boolean gcinfo		= FALSE;	/* -I */
 #endif
 
-#if !HPUX
+#if (!HPUX) && (!__linux__)
 extern int getopt (int argc, char **argv, const char *optstring);
 #endif
 extern int optind;
