@@ -247,6 +247,10 @@ extern int getgroups(int, int *);
 #define	setpgrp(a,b)	setpgrp()
 #endif
 
+#ifdef __linux__
+#define setpgrp(a,b)    setpgrp()
+#endif /* __linux __ */
+
 #if !HAS_LSTAT
 #define	lstat	stat
 #endif
@@ -285,4 +289,6 @@ extern void *qsort(
 /* setjmp */
 
 extern int setjmp(jmp_buf env);
+#ifndef __linux__
 extern noreturn longjmp(jmp_buf env, int val);
+#endif /* not __linux__ */
